class Range
  def center; (self.first + self.last)/2 end
end

class ItemsController < ApplicationController
  before_action :set_otem, only: [:show, :edit, :update, :destroy]
  caches_page :index, :list

  def list
    @items = Item.all
  end
  
  require 'geo/geo'
  def index
    cookies[:lat] ||= 50.0950
    cookies[:lon] ||= 14.3611
    @mappos = [cookies[:lat],cookies[:lon]]
    
    respond_to do |format|
      format.html  # není třeba poinsts, protože ty se nahrávají až do mapy podle toho jak se posouvá
      format.json {
        ## nacist vsechny body a uplatnit filtry z url
        @items = Item.includes(:neighbour).references(:neighbour)
        @items = @items.select{ |pt| pt.tags['CITYDISTRICT'] =~ /#{params[:citydistrict]}/ } if params[:citydistrict]
      
        ## vyfiltrovat body z tile
        @z,@x,@y = params['z'], params['x'], params['y']
        raise "Not enough coordinates (must have z,x,y)" unless [@x,@y,@z].compact.size == 3
        tile = Tile.new(@z,@x,@y)
        @items = @items.where(lat: tile.lat_range).where(lon: tile.lon_range)
 
        ## popupy
        ladim_popupy = true # tohle je treba dat tru pokazde kdyz ladim popupy
        @items = @items.map do |item|
          if item.cache_popup.nil? or ladim_popupy
            item.cache_popup = render_to_string partial: "#{item.typ}_popup", locals: {item: item}, layout: false, formats: 'html'
            if item.has_neighbour?
              item.cache_popup += "<hr>Spárováno s bodem:"
              item.cache_popup += render_to_string partial: "#{item.neighbour.typ}_popup", locals: {item: item.neighbour}, layout: false, formats: 'html'
            end
            item.save
          end
          item
        end
        render formats: 'json'
      }
		end
	end
  
  def testmobile
    render layout: false
  end

  # GET /items/1
  # GET /items/1.json
  def show
  end

  # GET /items/new
  def new
    @item = Item.new
  end

  # GET /items/1/edit
  def edit
  end

  def create
    @item = Item.new(item_params)

    respond_to do |format|
      if @item.save
        format.html { redirect_to @item, notice: 'Item was successfully created.' }
        format.json { render :show, status: :created, location: @item }
      else
        format.html { render :new }
        format.json { render json: @item.errors, status: :unprocessable_entity }
      end
    end
  end

  def update
    respond_to do |format|
      if @item.update(item_params)
        format.html { redirect_to @item, notice: 'Item was successfully updated.' }
        format.json { render :show, status: :ok, location: @item }
      else
        format.html { render :edit }
        format.json { render json: @item.errors, status: :unprocessable_entity }
      end
    end
  end

  def destroy
    @item.destroy
    respond_to do |format|
      format.html { redirect_to items_url, notice: 'Item was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_item
      @item = Item.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def item_params
      params.require(:item).permit(:lat,:lon)
    end
end
